==> certmanager-model-v1alpha3-6.8.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/AzureManagedIdentityFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class AzureManagedIdentityFluent<A extends AzureManagedIdentityFluent<A>> extends BaseFluent<A>{
  public AzureManagedIdentityFluent() {
  }
  public AzureManagedIdentityFluent(AzureManagedIdentity instance) {
    instance = (instance != null ? instance : new AzureManagedIdentity());

    if (instance != null) {
      this.withClientID(instance.getClientID());
      this.withResourceID(instance.getResourceID());
      this.withClientID(instance.getClientID());
      this.withResourceID(instance.getResourceID());
    }
  }
  private String clientID;
  private String resourceID;
  public String getClientID() {
    return this.clientID;
  }
  public A withClientID(String clientID) {
    this.clientID=clientID; return (A) this;
  }
  public boolean hasClientID() {
    return this.clientID != null;
  }
  public String getResourceID() {
    return this.resourceID;
  }
  public A withResourceID(String resourceID) {
    this.resourceID=resourceID; return (A) this;
  }
  public boolean hasResourceID() {
    return this.resourceID != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AzureManagedIdentityFluent that = (AzureManagedIdentityFluent) o;
    if (!java.util.Objects.equals(clientID, that.clientID)) return false;

    if (!java.util.Objects.equals(resourceID, that.resourceID)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(clientID,  resourceID,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clientID != null) { sb.append("clientID:"); sb.append(clientID + ","); }
    if (resourceID != null) { sb.append("resourceID:"); sb.append(resourceID); }
    sb.append("}");
    return sb.toString();
  }
  
}

==> certmanager-model-v1alpha3-6.9.0-sources.jar: io/fabric8/certmanager/api/model/acme/v1alpha3/AzureManagedIdentityFluent.java <==
package io.fabric8.certmanager.api.model.acme.v1alpha3;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.String;

/**
 * Generated
 */
@SuppressWarnings("unchecked")
public class AzureManagedIdentityFluent<A extends AzureManagedIdentityFluent<A>> extends BaseFluent<A>{
  public AzureManagedIdentityFluent() {
  }
  
  public AzureManagedIdentityFluent(AzureManagedIdentity instance) {
    this.copyInstance(instance);
  }
  private String clientID;
  private String resourceID;
  
  protected void copyInstance(AzureManagedIdentity instance) {
    instance = (instance != null ? instance : new AzureManagedIdentity());
  
    if (instance != null) {
        this.withClientID(instance.getClientID());
        this.withResourceID(instance.getResourceID());
        this.withClientID(instance.getClientID());
        this.withResourceID(instance.getResourceID());
      }
  }
  
  public String getClientID() {
    return this.clientID;
  }
  
  public A withClientID(String clientID) {
    this.clientID=clientID; return (A) this;
  }
  
  public boolean hasClientID() {
    return this.clientID != null;
  }
  
  public String getResourceID() {
    return this.resourceID;
  }
  
  public A withResourceID(String resourceID) {
    this.resourceID=resourceID; return (A) this;
  }
  
  public boolean hasResourceID() {
    return this.resourceID != null;
  }
  
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    AzureManagedIdentityFluent that = (AzureManagedIdentityFluent) o;
    if (!java.util.Objects.equals(clientID, that.clientID)) return false;
  
    if (!java.util.Objects.equals(resourceID, that.resourceID)) return false;
  
    return true;
  }
  
  public int hashCode() {
    return java.util.Objects.hash(clientID,  resourceID,  super.hashCode());
  }
  
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (clientID != null) { sb.append("clientID:"); sb.append(clientID + ","); }
    if (resourceID != null) { sb.append("resourceID:"); sb.append(resourceID); }
    sb.append("}");
    return sb.toString();
  }
  

}
